<?php
/**
 * @copyright  Intelligent IT SRL 2018
 */

class SmartBill_Data_Logger{
    private $order_id;
    private $existing_data;
    /**
     * Getter for Prestashop ID
     *
     * @return void
     */
    public function get_order_id()
    {
        return $this->order_id;
    }

    /**
     * Constructor - if data does not exist - we do not set the order_id because we need to retrieve it
     * in a separate call if data exists (in order to append JSON exchanged data) and we do not want false negatives
     *
     * @return void
     */
    public function __construct($order_id)
    {
        $existing_data = $this->get_db_log($order_id);

        //if data exists, fill in the details
        if (! empty($existing_data)){
            $this->existing_data = $existing_data;
            $this->order_id = $order_id;
        } else {
            $this->existing_data = null;
        }
    }

    /**
     * This function retrieves existing data by Prestashop order ID
     *
     * @return void
     */
    public function get_data($order_id, $key = null)
    {
        if (!is_numeric($order_id) || !$key) return false;

        $existing_data = $this->get_db_log($order_id);
        if ( $key && isset($existing_data[$key])) return $existing_data[$key];
        return $existing_data;
    }

    /**
     * This function saves exchanged data between Prestashop and SmartBill Cloud
     *
     * @return void
     */
    public function set_data($order_id, $key, $value)
    {
        if (!is_numeric($order_id) || !$key) return false;
        $this->existing_data[$key] = $value;
        return $this;
    }

    /**
     * Save information into database
     *
     * @return void
     */
    public function save($order_id = null)
    {
        if (! $this->existing_data) return false;
        if (! $this->get_order_id()){
            $this->order_id = $order_id;
        }
        $existing_data = pSQL(serialize($this->existing_data));

        $status = Db::getInstance()->execute("UPDATE  " . _DB_PREFIX_ . "orders SET `smartbill_invoice_log` = '$existing_data' WHERE id_order = {$order_id}");

        return $status;
    }

    private function get_db_log($order_id) {

        $order_sql = Db::getInstance()->getRow("SELECT smartbill_invoice_log FROM " . _DB_PREFIX_ . "orders WHERE id_order = {$order_id}");
        return unserialize($order_sql['smartbill_invoice_log']);
    }
    
    /**
     * get_document_id
     * *Getter for SmartBill Invoice Id 
     * @return Integer
     */
    public function get_document_id(){
        return  $this->existing_data['smartbill_invoice_id'];
    }

}
